@@ -91,7 +91,8 @@ void MobileShellSettings::setNavigationPanelEnabled(bool navigationPanelEnabled)
     group.writeEntry("navigationPanelEnabled", navigationPanelEnabled, KConfigGroup::Notify);
     m_config->sync();
 
-    updateNavigationBarsInPlasma(navigationPanelEnabled);
+    // TODO: Gesture only mode setting is disabled until we get the kwin effect gesture working: https://invent.kde.org/plasma/plasma-mobile/-/issues/300
+    // updateNavigationBarsInPlasma(navigationPanelEnabled);
 }
 
 bool MobileShellSettings::alwaysShowKeyboardToggleOnNavigationPanel() const
