@@ -9,6 +9,7 @@
 #include <kscreen/config.h>
 
 #include "brightnesscontrolinterface.h"
+#include "colorssettings.h"
 
 class PrepareUtil : public QObject
 {
@@ -18,6 +19,7 @@ class PrepareUtil : public QObject
     Q_PROPERTY(int brightness READ brightness WRITE setBrightness NOTIFY brightnessChanged);
     Q_PROPERTY(int maxBrightness READ maxBrightness NOTIFY maxBrightnessChanged)
     Q_PROPERTY(bool brightnessAvailable READ brightnessAvailable NOTIFY brightnessAvailableChanged)
+    Q_PROPERTY(bool usingDarkTheme READ usingDarkTheme WRITE setUsingDarkTheme NOTIFY usingDarkThemeChanged)
 
 public:
     PrepareUtil(QObject *parent = nullptr);
@@ -34,11 +36,15 @@ public:
 
     bool brightnessAvailable() const;
 
+    bool usingDarkTheme() const;
+    void setUsingDarkTheme(bool usingDarkTheme);
+
 Q_SIGNALS:
     void scalingChanged();
     void brightnessChanged();
     void maxBrightnessChanged();
     void brightnessAvailableChanged();
+    void usingDarkThemeChanged();
 
 private Q_SLOTS:
     void fetchBrightness();
@@ -48,7 +54,9 @@ private:
     int m_scaling;
     int m_brightness;
     int m_maxBrightness;
+    bool m_usingDarkTheme;
 
+    ColorsSettings *m_colorsSettings;
     KScreen::ConfigPtr m_config;
     org::kde::Solid::PowerManagement::Actions::BrightnessControl *m_brightnessInterface;
     QDBusServiceWatcher *m_brightnessInterfaceWatcher;
