@@ -143,6 +143,11 @@ bool Modem::needsAPNAdded() const
 
 bool Modem::mobileDataEnabled() const
 {
+    // if wwan is globally disabled
+    if (!NetworkManager::isWwanEnabled()) {
+        return false;
+    }
+
     // no modem -> no mobile data -> report disabled
     if (!m_nmModem) {
         return false;
@@ -171,20 +176,20 @@ bool Modem::mobileDataEnabled() const
 
 void Modem::setMobileDataEnabled(bool enabled)
 {
+    // ensure that wwan is on
+    if (enabled && !NetworkManager::isWwanEnabled()) {
+        NetworkManager::setWwanEnabled(true);
+    }
+
     if (!m_nmModem) {
         return;
     }
 
-    if (!enabled) {
-        m_nmModem->setAutoconnect(false);
-        // we need to also set all connections to not autoconnect (#182)
-        for (NetworkManager::Connection::Ptr con : m_nmModem->availableConnections()) {
-            con->settings()->setAutoconnect(false);
-            con->update(con->settings()->toMap());
-        }
-        m_nmModem->disconnectInterface();
-    } else {
+    if (enabled) {
+        // enable mobile data...
+
         m_nmModem->setAutoconnect(true);
+
         // activate the connection that was last used
         QDateTime latestTimestamp;
         NetworkManager::Connection::Ptr latestCon;
@@ -199,6 +204,7 @@ void Modem::setMobileDataEnabled(bool enabled)
                 latestCon = con;
             }
         }
+
         // if we found the last used connection
         if (!latestCon.isNull()) {
             // set it to autoconnect and connect it immediately
@@ -206,6 +212,22 @@ void Modem::setMobileDataEnabled(bool enabled)
             latestCon->update(latestCon->settings()->toMap());
             NetworkManager::activateConnection(latestCon->path(), m_nmModem->uni(), "");
         }
+
+    } else {
+        // disable mobile data...
+
+        // we do not call NetworkManager::setWwanEnabled(false), because it turns off cellular
+
+        // turn off autoconnect
+        m_nmModem->setAutoconnect(false);
+        // we need to also set all connections to not autoconnect (#182)
+        for (NetworkManager::Connection::Ptr con : m_nmModem->availableConnections()) {
+            con->settings()->setAutoconnect(false);
+            con->update(con->settings()->toMap());
+        }
+
+        // disconnect network
+        m_nmModem->disconnectInterface();
     }
 }
 
